==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/floppy/dialogs_nl.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Het lijkt erop dat we er eindelijk uit zijn.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Denk je dat dat hem is?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Hoe kan alles nou op een diskette passen?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Moet je zien hoeveel groter het is dan ik. Het is een drieeneenkwart-METER diskette.")


dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
dialogStr("Dat is beter. Grootse plannen, grootse diskette. Logisch.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Denk je dat we die op kunnen tillen?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Dat wordt lastig.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Ik denk niet dat het gaat lukken. Waarom zouden ze het hier verstoppen als we het makkelijk op konden tillen?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Rustig, of ik breek je contactjes af!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Zie je dat stalen kruis? Dat is het graf van onze hoop.")


dialogId("disk-m-depres", "font_small", "Don`t be always so gloomy. I can`t bear it.")
dialogStr("Wees toch niet zo'n zwartkijker. Ik kan daar niet tegen.")


dialogId("disk-m-nahrat", "font_small", "Wouldn`t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Zou het niet goed genoeg zijn als we dat plan van de floppy downloaden en op ons notebook zetten?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Je hebt gelijk. Pak het notebook er maar bij.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("O, verdorie! Ik heb het thuis laten liggen.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Zullen we dan maar terug gaan?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Nee, dat nooit. Misschien vind je het grappig, maar mijn vinnen doen pijn.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Zelf weten. Ik vraag me af hoe je het dan wel wilt oplossen.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("En wat als er niks op deze floppie staat? Wat als die hier alleen maar is om ons voor de gek te houden?")


dialogId("disk-v-neverim", "font_big", "I don`t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Daar geloof ik niks van. Is er nog iets dat nog moeilijker hieruit te krijgen is?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Wat zijn dat voor kleine beestjes?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Dat zijn vast computervirussen.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Bah. Monstertjes.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn`t be happy if we pour them on their desktop.")
dialogStr("We moeten wel voorzichtig zijn en ze niet perongeluk meenemen. De speler zou niet blij zijn als die op zijn of haar desktop belanden.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Het is ons doel om deze diskette mee te nemen.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won`t move me easily!")
dialogStr("Mij krijg je niet zo snel van m'n plek!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Dat was slim!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Oeps!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Verdorie!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("O!")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Auw!")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Ja.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Laat me met rust!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/dialogs_nl.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Het lijkt erop dat we er eindelijk uit zijn.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Denk je dat dat hem is?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Hoe kan alles nou op één drieeneenhalf-inch diskette passen?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Moet je zien hoeveel groter het is dan ik. Het is een drieeneenhalf-METER diskette.")


dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("Dat is beter. Grootse plannen, grootse diskette. Logisch.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Denk je dat we die op kunnen tillen?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Dat wordt lastig.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Ik denk niet dat het gaat lukken. Waarom zouden ze het hier verstoppen als we het makkelijk op konden tillen?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Rustig, of ik breek je contactjes af!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Zie je dat stalen kruis? Dat is het graf van onze hoop.")


dialogId("disk-m-depres", "font_small", "Don’t be always so gloomy. I can’t bear it.")
dialogStr("Wees toch niet zo'n zwartkijker. Ik kan daar niet tegen.")


dialogId("disk-m-nahrat", "font_small", "Wouldn’t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Zou het niet goed genoeg zijn als we dat plan van de floppy downloaden en op ons notebook zetten?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Je hebt gelijk. Pak het notebook er maar bij.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("O, verdorie! Ik heb het thuis laten liggen.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Zullen we dan maar terug gaan?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Nee, dat nooit. Misschien vind jij het grappig, maar mijn vinnen doen pijn.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Zelf weten. Ik vraag me af hoe je het dan wel wilt oplossen.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("En wat als er niks op deze floppie staat? Wat als die hier alleen maar is om ons voor de gek te houden?")


dialogId("disk-v-neverim", "font_big", "I don’t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Daar geloof ik niks van. Is er nog iets dat nog moeilijker hieruit te krijgen is?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Wat zijn dat voor kleine beestjes?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Dat zijn vast computervirussen.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Bah. Monstertjes.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
dialogStr("We moeten wel voorzichtig zijn en ze niet perongeluk meenemen. De speler zou niet blij zijn als die op zijn of haar computer belanden.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Het is ons doel om deze diskette mee te nemen.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won’t move me easily!")
dialogStr("Mij krijg je niet zo snel van m'n plek!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Dat was slim!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Oeps!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Verdorie!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("O!")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Auw!")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Ja.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Laat me met rust!")
